# Acknowledgment

This client package was created by [Giuseppe Dilillo](https://gdilillo.com/).

It would not exist without the work of Fabrizio Fabri on the REST API, and the supervision of Alessandro Maselli.

We thank Andrea Tramacere for his insights and feedback.

The original [SED Builder](https://tools.ssdc.asi.it/SED/) service is a work of Capalbi, Cutini, Gasparrini, Giommi, Maselli, Primavera, Stratta and others[^1].


I hope you enjoy it!

[^1]: Please if you worked on SED Builder and you are missing from this list, let me know!